# TimeSlicedElpNetMetricsGeneratedReason

Specify the reason why the metrics are generated by the certain order action. 

## Enum

* `INCREASEQUANTITY` (value: `'IncreaseQuantity'`)

* `DECREASEQUANTITY` (value: `'DecreaseQuantity'`)

* `CHANGEPRICE` (value: `'ChangePrice'`)

* `EXTENSION` (value: `'Extension'`)

* `CONTRACTION` (value: `'Contraction'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


